==> eiffelstudio-18.11.10.2592.tar: F_code/C4/as165.c <==
/*
 * Code for class AST_FORMAL_GENERICS_PASS2
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "as165.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {AST_FORMAL_GENERICS_PASS2}.make */
void F205_3045 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLIU(4);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg2;
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg3;
	RTLE;
}

/* {AST_FORMAL_GENERICS_PASS2}.has_node_changed */
EIF_BOOLEAN F205_3046 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) != NULL);
}

/* {AST_FORMAL_GENERICS_PASS2}.consume_node */
void F205_3047 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) NULL;
	RTLE;
}

/* {AST_FORMAL_GENERICS_PASS2}.last_consumed_node */
EIF_REFERENCE F205_3048 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {AST_FORMAL_GENERICS_PASS2}.new_node */
EIF_REFERENCE F205_3049 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {AST_FORMAL_GENERICS_PASS2}.ast_factory */
EIF_REFERENCE F205_3050 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {AST_FORMAL_GENERICS_PASS2}.suppliers */
EIF_REFERENCE F205_3051 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {AST_FORMAL_GENERICS_PASS2}.formal_parameters */
EIF_REFERENCE F205_3052 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {AST_FORMAL_GENERICS_PASS2}.process_formal_as */
void F205_3053 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTGC;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_class_type_as */
void F205_3054 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	EIF_BOOLEAN tb5;
	RTLD;
	
	RTLI(8);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,loc4);
	RTLR(3,tr1);
	RTLR(4,Current);
	RTLR(5,loc5);
	RTLR(6,loc2);
	RTLR(7,loc3);
	RTLIU(8);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(RTCW(arg1));
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R9533[Dtype(arg1)-1184])(RTCW(arg1));
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		F28_460(RTCW(tr1), loc1);
		F773_5576(loc4);
		for (;;) {
			tb1 = F727_5218(loc4);
			if (tb1) break;
			tr1 = F773_5550(loc4);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9023[Dtype(tr1)-1113])(RTCW(tr1), Current);
			if (F205_3046(Current)) {
				F205_3047(Current);
				tr1 = *(EIF_REFERENCE *)(Current);
				loc5 = tr1;
				if (EIF_TEST(loc5)) {
					F773_5589(loc4, loc5);
				}
			}
			F773_5578(loc4);
		}
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		F773_5576(RTCW(tr1));
		for (;;) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			tb2 = F727_5218(RTCW(tr1));
			if (tb2) break;
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			loc2 = F773_5550(RTCW(tr1));
			tr1 = *(EIF_REFERENCE *)(RTCW(loc2));
			tb3 = F1262_13218(RTCW(loc1), tr1);
			if (tb3) {
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
				tb3 = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_1_6_);
				tb4 = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_1_7_);
				tb5 = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_1_4_);
				loc3 = F304_4285(RTCW(tr1), loc1, tb3, tb4, tb5, NULL);
				if ((EIF_BOOLEAN)(loc3 != NULL)) {
					ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc2)+ _LNGOFF_1_8_0_6_);
					F1183_12312(RTCW(loc3), ti4_1);
				}
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
				F773_5577(RTCW(tr1));
			}
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			F773_5578(RTCW(tr1));
		}
		if ((EIF_BOOLEAN)(loc3 != NULL)) {
			RTAR(Current, loc3);
			*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc3;
		} else {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
			F28_460(RTCW(tr1), loc1);
		}
	}
	RTLE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_generic_class_type_as */
void F205_3055 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F205_3054(Current, arg1);
}

/* {AST_FORMAL_GENERICS_PASS2}.process_named_tuple_type_as */
void F205_3056 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,Current);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTGC;
	loc1 = F1180_12265(RTCW(arg1));
	F773_5576(RTCW(loc1));
	for (;;) {
		tb1 = F727_5218(RTCW(loc1));
		if (tb1) break;
		tr1 = F773_5550(RTCW(loc1));
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9023[Dtype(tr1)-1113])(RTCW(tr1), Current);
		if (F205_3046(Current)) {
			F205_3047(Current);
			tr1 = *(EIF_REFERENCE *)(Current);
			loc2 = tr1;
			if (EIF_TEST(loc2)) {
				tr1 = F773_5550(RTCW(loc1));
				F1135_11880(RTCW(tr1), loc2);
			}
		}
		F773_5578(RTCW(loc1));
	}
	RTLE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_like_id_as */
void F205_3057 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTGC;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_like_cur_as */
void F205_3058 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTGC;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_qualified_anchored_type_as */
void F205_3059 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9023[Dtype(tr1)-1113])(RTCW(tr1), Current);
	RTLE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_type_dec_as */
void F205_3060 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9023[Dtype(tr1)-1113])(RTCW(tr1), Current);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		F1135_11880(RTCW(arg1), loc1);
	}
	RTLE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_none_type_as */
void F205_3061 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTGC;
}

void EIF_Minit165 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/as165.c <==
/*
 * Code for class AST_FORMAL_GENERICS_PASS2
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "as165.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {AST_FORMAL_GENERICS_PASS2}.make */
void F205_3054 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLIU(4);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg2;
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg3;
	RTLE;
}

/* {AST_FORMAL_GENERICS_PASS2}.has_node_changed */
EIF_BOOLEAN F205_3055 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) != NULL);
}

/* {AST_FORMAL_GENERICS_PASS2}.consume_node */
void F205_3056 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) NULL;
	RTLE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_formal_as */
void F205_3062 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTGC;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_class_type_as */
void F205_3063 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	EIF_BOOLEAN tb5;
	RTLD;
	
	RTLI(8);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,loc4);
	RTLR(3,tr1);
	RTLR(4,Current);
	RTLR(5,loc5);
	RTLR(6,loc2);
	RTLR(7,loc3);
	RTLIU(8);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(RTCW(arg1));
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R9563[Dtype(RTCW(arg1))-1189])(arg1);
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		F25_261(RTCW(tr1), loc1);
		F773_5587(loc4);
		for (;;) {
			tb1 = F727_5229(loc4);
			if (tb1) break;
			tr1 = F773_5561(loc4);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9053[Dtype(RTCW(tr1))-1118])(tr1, Current);
			if (F205_3055(Current)) {
				F205_3056(Current);
				tr1 = *(EIF_REFERENCE *)(Current);
				loc5 = tr1;
				if (EIF_TEST(loc5)) {
					F773_5600(loc4, loc5);
				}
			}
			F773_5589(loc4);
		}
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		F773_5587(RTCW(tr1));
		for (;;) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			tb2 = F727_5229(RTCW(tr1));
			if (tb2) break;
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			loc2 = F773_5561(RTCW(tr1));
			tr1 = *(EIF_REFERENCE *)(RTCW(loc2));
			tb3 = F1265_13241(RTCW(loc1), tr1);
			if (tb3) {
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
				tb3 = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_1_6_);
				tb4 = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_1_7_);
				tb5 = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_1_4_);
				loc3 = F305_4295(RTCW(tr1), loc1, tb3, tb4, tb5, NULL);
				if ((EIF_BOOLEAN)(loc3 != NULL)) {
					ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc2)+ _LNGOFF_1_8_0_6_);
					F1188_12348(RTCW(loc3), ti4_1);
				}
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
				F773_5588(RTCW(tr1));
			}
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			F773_5589(RTCW(tr1));
		}
		if ((EIF_BOOLEAN)(loc3 != NULL)) {
			RTAR(Current, loc3);
			*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc3;
		} else {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
			F25_261(RTCW(tr1), loc1);
		}
	}
	RTLE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_generic_class_type_as */
void F205_3064 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F205_3063(Current, arg1);
}

/* {AST_FORMAL_GENERICS_PASS2}.process_named_tuple_type_as */
void F205_3065 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,Current);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTGC;
	loc1 = F1184_12292(RTCW(arg1));
	F773_5587(RTCW(loc1));
	for (;;) {
		tb1 = F727_5229(RTCW(loc1));
		if (tb1) break;
		tr1 = F773_5561(RTCW(loc1));
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9053[Dtype(RTCW(tr1))-1118])(tr1, Current);
		if (F205_3055(Current)) {
			F205_3056(Current);
			tr1 = *(EIF_REFERENCE *)(Current);
			loc2 = tr1;
			if (EIF_TEST(loc2)) {
				tr1 = F773_5561(RTCW(loc1));
				F1140_11916(RTCW(tr1), loc2);
			}
		}
		F773_5589(RTCW(loc1));
	}
	RTLE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_like_id_as */
void F205_3066 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTGC;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_like_cur_as */
void F205_3067 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTGC;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_qualified_anchored_type_as */
void F205_3068 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9053[Dtype(RTCW(tr1))-1118])(tr1, Current);
	RTLE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_type_dec_as */
void F205_3069 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9053[Dtype(RTCW(tr1))-1118])(tr1, Current);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		F1140_11916(RTCW(arg1), loc1);
	}
	RTLE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_none_type_as */
void F205_3070 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTGC;
}

void EIF_Minit165 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
